@@ -1,15 +1,15 @@
 #!/usr/bin/env seed
 // Returns: 0
 // STDIN:
-// STDOUT:2.000000
+// STDOUT:2
 // STDERR:
- 
+
 Gtk = imports.gi.Gtk;
-Gtk.init(null, null);
+Gtk.init(Seed.argv);
 
 b = new Gtk.Button();
 b.relief = Gtk.ReliefStyle.NONE;
 
-Seed.print(Gtk.ReliefStyle.NONE);
+print(Gtk.ReliefStyle.NONE);
 
 
